;;; scim-bridge-zh-tr.el

;; Copyright (C) 2008 S. Irie
;; Copyright (C) 2008 Andy Stewart

;; Author: S. Irie
;; Maintainer: S. Irie
;; Keywords: Input Method, i18n

(defconst scim-bridge-zh-tr-version "0.7.0.1")

;; This program is free software; you can redistribute it and/or
;; modify it under the terms of the GNU General Public License as
;; published by the Free Software Foundation; either version 2, or
;; (at your option) any later version.

;; It is distributed in the hope that it will be useful, but WITHOUT
;; ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
;; or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public
;; License for more details.

;; You should have received a copy of the GNU General Public
;; License along with this program; if not, write to the Free
;; Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
;; MA 02111-1307 USA

;;; Commentary:

;; The Smart Common Input Method platform (SCIM) is an input
;; method (IM) platform containing support for more than thirty
;; languages (CJK and many European languages) for POSIX-style
;; operating systems including Linux and BSD.

;; scim-bridge.el is SCIM-Bridge client for GNU Emacs. It is,
;; however, not part of official SCIM-Bridge.

;; This program changes the documentation strings of the variables
;; and functions defined in scim-bridge.el into the equivalents
;; which are written in Traditional Chinese.

;;
;; Installation:
;;
;; First, save this file (scim-bridge-zh-tr.el) and scim-bridge.el
;; in a directory listed in load-path, and then byte-compile them.
;;
;; Put the following in your .emacs file:
;;
;;   (require 'scim-bridge-zh-tr)
;;
;; After that, execute Emacs by typing on command line:
;;
;;   XMODIFIERS=@im=none emacs
;;
;; and turn on scim-mode:
;;
;;   M-x scim-mode
;;
;;
;; Here is the example of settings in .emacs:
;;
;;   (require 'scim-bridge-zh-tr)
;;   ;; Use C-SPC for Set Mark command
;;   (scim-define-common-key ?\C-\  nil)
;;   ;; Use C-/ for Undo command
;;   (scim-define-common-key ?\C-/ nil)
;;   ;; Change cursor color depending on SCIM status
;;   (setq scim-cursor-color "red")
;;   ;; Turn on scim-mode automatically
;;   (scim-mode t)
;;
;;
;; Note that this program requires GNU Emacs 22 or later, and
;; doesn't work when Emacs is running on terminal emulator.
;;

;; History:
;; 2008-10-08  S. Irie
;;         * First release
;;         * Version 0.7.0.1
;;
;; 2008-10-04  Andy Stewart
;;         * Translated from scim-bridge-en.el
;;         * Version 0.7.0

;; ToDo:

;;; Code:

(require 'scim-bridge)

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;; Apply translations
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(scim-set-group-doc
 'scim
 "智能通用輸入法平台")

(scim-set-variable-doc
 'scim-mode
 "切換 scim-mode.
直接設置這個變量冇有效果;
使用 \\[customize] 或 函數 `scim-mode'.")

;; Basic settings
(scim-set-group-doc
 'scim-basic
 "操作設置, 例如模式設置和鍵盤設置")

(scim-set-variable-doc
 'scim-mode-local
 "如果值為非空 (non-nil), 輸入法內容會對每一個緩存(buffer)進行注冊以使
各個緩存(buffers)可以單獨切換輸入法. 否則, 輸入法進行全局切換.")

(scim-set-variable-doc
 'scim-common-function-key-list
 "這個列表(list)指示SCIM在直接插入模式和預編輯模式接管的按鍵.
你可以使用函數 `scim-define-common-key' 添加或刪除其元素.
注意: 不要在這個選項設置前綴按鍵, 例如 ESC 或 C-X.
如果你要這麼做, Emacs可能會不可操作.")

(scim-set-variable-doc
 'scim-preedit-function-key-list
 "這個列表(list)指示SCIM在預編輯區域存在時接管的按鍵.
你可以使用函數 `scim-define-preedit-key' 添加或刪除其元素.")

(scim-set-variable-doc
 'scim-use-kana-ro-key
 "如果你用jp-106鍵盤和日本kana輸入法(Japanese kana typing method),
開啟這個選項(non-nil)以使不按shift按鍵輸入 kanna 字符 `ろ'.
這個選項可以使用 `xmodmap' 命令臨時的修改 X-windows 係統的鍵盤設置.")

(scim-set-variable-doc
 'scim-key-release-delay
 "如果你用jp-106鍵盤和基於SCIM-Anthy的日本thumb shift輸入法 (Japanese
thumb shift typing method). 設置按鍵的時間延遲 (單位: 秒).
設置一個小於SCIM-Anthy中 \"同時按下按鍵的時間設置\"的值."
 '(choice (const :tag "none" nil)
          (number :tag "delay (in seconds)"
                  :value 0.1)))

(scim-set-variable-doc
 'scim-undo-by-committed-string
 "如果這個值為空 (nil),
撤銷執行並使一些短的轉換字符串 (committed string) 連在一齊或劃分長的
轉換字符串(不操過 20 個字符). 否則, 每一個轉換字符串執行撤銷.")

(scim-set-variable-doc
 'scim-clear-preedit-when-unexpected-event
 "當一個意想不到的事件發生在預編輯時, 預編輯區域被清空, 並設置這個值為
非空 (non-nil). 意想不到的事件是指, 比如, 字符串被鼠標粘帖了.")

;; Appearance
(scim-set-group-doc
 'scim-appearance
 "外觀, 候選窗口, 等等.")

(scim-set-face-doc
 'scim-preedit-default-face
 "這個外觀顯示整個預編輯區域.")

(scim-set-face-doc
 'scim-preedit-underline-face
 "整個外觀對應於 SCIM圖形設置工具文本屬性中的 下劃線 (`Underline').")

(scim-set-face-doc
 'scim-preedit-highlight-face
 "整個外觀對應於 SCIM圖形設置工具文本屬性中的 高亮 (`Highlight').")

(scim-set-face-doc
 'scim-preedit-reverse-face
 "整個外觀對應於 SCIM圖形設置工具文本屬性中的 背景 (`Reverse').")

(scim-set-variable-doc
 'scim-cursor-color
 "如果這個值是一個字符串, 它指示出當 SCIM 開啟時光標所應用的顏色.
如果這個值為一個單元 (cons cell), 它的第一個 (car) 和 剩下的 (cdr) 分彆指示
SCIM 開啟 和 關閉 時的光標顏色. 如果這個值為空 (nil) 意味著不控製光標的顏色.
注意: 當使用 SCIM 圖形設置工具時, 光標狀態和顏色可能會被破壞.
因為當 SCIM 設置改變時會使所有緩存 (buffers)的 SCIM 關閉而不進行任何提示.
為了解決這個矛盾, 以可以用命令 `scim-reset-imcontext-statuses'."
 ;; ** Don't translate `:value' properties!! **
 '(choice (const :tag "none (nil)" nil)
          (color :tag "red" :format "red (%{sample%})\n" :value "red")
          (color :tag "blue" :format "blue (%{sample%})\n" :value "blue")
          (color :tag "green" :format "green (%{sample%})\n" :value "green")
          (color :tag "other" :value "red")
          (cons  :tag "other (ON . OFF)"
                 (color :format "ON: %v (%{sample%})  " :value "red")
                 (color :format "OFF: %v (%{sample%})\n" :value "blue"))))

(scim-set-variable-doc
 'scim-cursor-type-for-candidate
 "這個選項指定預編輯窗口顯示候選變換時光標的形狀.
如果這個指為空 (nil) 意味者光標形狀冇有改變."
 '(choice (const :tag "default (nil)" nil)
          (const :tag "box" box)
          (const :tag "bar" bar)
          (cons :tag "bar (specify width)"
                (const :format "" bar)
                (integer :tag "width" :value 1))
          (const :tag "invisible" (bar . 0))))

(scim-set-variable-doc
 'scim-put-cursor-on-candidate
 "如果這個值為非空 (non-nil) 時, 當預編輯區域顯示候選轉換時, 光標方在
選擇段的位置, 否則光標方在預編輯區域的頂端.")

(scim-set-variable-doc
 'scim-adjust-window-x-position
 "這個選項指定是否對候選窗口的位置進行調整, 候選窗口可能按縱向排列.
如果這個值為 'gnome', 會使用 GNOME 桌面環境的字體大小進行調整.
否則, 如果這個值是整數, 指示從正常位置處的進行調整的像素數量.
這個值不適用於候選窗口總是顯示的輸入法, 比如 SCIM-pinyin (中文).
因為當光標在屏幕底部時, 窗口會隱藏光標."
 '(choice (const :tag "use GNOME's font size" gnome)
          (integer :tag "specify by pixel number" :value 24)
          (const :tag "off" nil)))

(scim-set-variable-doc
 'scim-adjust-window-y-position
 "如果這個值為非空 (non-nil), 候選窗口縱向位置會相對於命令 `xwininfo'
得到光標的底部進行調整. 否則, 不進行調整. 因此窗口可能會在精確位置的下面一點.")

(scim-set-variable-doc
 'scim-prediction-window-position
 "(隻用於日本輸入法) 這個值以 (POS . ADJ) 的形式給出.
如果 POS 的值為非空 (non-nil), 預想的窗口會顯示在預編輯區域的開頭.
如果 ADJ 的值為非空 (non-nil), 橫向調整, 調整值和
`scim-adjust-window-x-position' 相同."
 '(cons
   (choice :tag "Position"
           (const :tag "Tail of preediting area" nil)
           (const :tag "Head of preediting area" t))
   (choice :tag "Adjustment"
           (const :tag "same as conversion window" t)
           (const :tag "off" nil))))

(scim-set-variable-doc
 'scim-mode-line-string
 "這個變量指定一個當 scim-mode 激活時顯示在 mode-line 上的描述
scim-mode 的字符串.")

;; Advanced settings
(scim-set-group-doc
 'scim-expert
 "高級設置")

(scim-set-variable-doc
 'scim-focus-update-interval
 "窗口更新周期的時間間隔, 單位是秒.")

(scim-set-variable-doc
 'scim-focus-update-interval-long
 "當窗口不能用命令 `xgrop' 處理時用 `xwininfo' 替代,
但是不是用 `scim-focus-update-interval' 而是用這個值作為一個更新周期.")

(scim-set-variable-doc
 'scim-kana-ro-x-keysym
 "當日本 kana-RO 按鍵使用時, 這個選項指定事件對應於 X window 係統給出的
替代的按鍵係統符號. 這個程序設置替代按鍵係統為了從 yen-mark 按鍵中區彆反斜線
符號按鍵.")

(scim-set-variable-doc
 'scim-kana-ro-key-symbol
 "當日本 kana-RO 按鍵使用時, 這個選項指定事件對應於 `scim-kana-ro-x-keysym'
給出的替代的按鍵係統符號. 這個程序設置替代按鍵係統為了從 yen-mark 按鍵中區彆
反斜線符號按鍵."
 '(choice (symbol)
          (const :tag "none" nil)))

(scim-set-variable-doc
 'scim-bridge-timeout
 "如果冇有特殊的原因不要改變這個設置.")

(scim-set-variable-doc
 'scim-bridge-wait-reply
 "如果冇有特殊的原因不要改變這個設置.")

(scim-set-variable-doc
 'scim-bridge-socket-use-script
 "如果這個值是非空的 (non-nil), 使用用戶腳本替代 UNIX 域名套接字 (UNIX
domain socket) 內置的函數 `make-network-process'.
當 Emacs 版本是 22 或 以後的版本時, 這個腳本通常不是必需的.")

(scim-set-variable-doc
 'scim-bridge-socket-script-path
 "套接字腳本的目的目錄.
如果目錄不存在, 自動創建一個.")

(scim-set-variable-doc
 'scim-bridge-socket-script-name
 "套接字腳本的文件名稱.")

(scim-set-variable-doc
 'scim-bridge-socket-script
 "套接字腳本的真正內容.
第一個命令行參數必需為套接字(socket)名字.")

(scim-set-variable-doc
 'scim-meta-key-exists
 "如果鍵盤存在 mata 按鍵修改, 設置這個值為 t.
當自動判定不能很好工作時, 請在 `scim-bridge.el' 加載前手動設置這個值.")

(scim-set-variable-doc
 'scim-tmp-buffer-name
 "這個是用來和代理 (agent) 進行通信的緩存的名字.")

(scim-set-variable-doc
 'scim-incompatible-mode-hooks
 "當這個勾子 (hooks) 運行, scim-mode-map變得不正確.")

;; Functions
(scim-set-function-doc
 'scim-set-group-doc
 "改變組的文檔字符串.
如果字符串 (STRING) 為空 (empty or nil), 文檔字符串保留原來的.")

(scim-set-function-doc
 'scim-set-variable-doc
 "改變變量的文檔字符串.
如果字符串 (STRING) 為空 (empty or nil), 文檔字符串保留原來的.
如果自定義類型 (CUSTOM-TYPE) 為非空 (non-nil), 它設置為變量 (VARIABLE)的
`custom-type' 屬性, 符合 `defcustom' 中的 :type 關鍵字.")

(scim-set-function-doc
 'scim-set-face-doc
 "改變外觀的文檔字符串.
如果字符串 (STRING) 為空 (empty or nil), 文檔字符串保留原來的.")

(scim-set-function-doc
 'scim-set-function-doc
 "改變函數的文檔字符串.
如果字符串 (STRING) 為空 (empty or nil), 文檔字符串保留原來的.")

(scim-set-function-doc
 'scim-define-common-key
 "SCIM在預編輯時接管的特殊的按鍵事件.
如果操作 (HANDLE) 為非空 (non-nil), SCIM根據給出的按鍵 (KEY) 進行按鍵事件操作.
當給出的按鍵是一個數組時, 它不會指示按鍵序列, 但是對單一按鍵進行多重定義.
當調用函數 `scim-update-key-bindings' 或 重新啟動 scim-mode 以使設置生效時
這個值是必需的.")

(scim-set-function-doc
 'scim-define-preedit-key
 "SCIM在預編輯時接管的特殊的按鍵事件.
如果操作 (HANDLE) 為非空 (non-nil), SCIM根據給出的按鍵 (KEY) 進行按鍵事件操作.
當給出的按鍵是一個數組時, 它不會指示按鍵序列, 但是對單一按鍵進行多重定義.
當調用函數 `scim-update-key-bindings' 或 重新啟動 scim-mode 以使設置生效時
這個值是必需的.")

(scim-set-function-doc
 'scim-reset-imcontext-statuses
 "重新設置保持每個緩存(buffer)的輸入法內容的狀態以正確顯示光標的顏色.
這個命令在使用 SCIM 圖形設置工具後可能會有用.")

(scim-set-function-doc
 'scim-get-frame-extents
 "返回框架(frame)邊緣的像素寬度 (left right top bottom).
這裡, `top' 是指框架標題欄的高度.")

(scim-set-function-doc
 'scim-frame-header-height
 "返回菜單欄和工具欄的總的高度.
這個函數返回的值不是那麼精確.")

(scim-set-function-doc
 'scim-real-frame-header-height
 "返回菜單欄和工具欄的總的高度.
這個函數返回的值非常精確, 但是這個函數比 `scim-frame-header-height' 要慢很多.")

(scim-set-function-doc
 'scim-compute-pixel-position
 "返回屏幕上點的像素位置 (X . Y).
這個值顯示字符左上角的坐標.")

(scim-set-function-doc
 'scim-get-gnome-font-size
 "返回GNOME環境中應用字體的像素大小.
當設置屏幕分辨率(點/英寸)時這個值是必需的, 使用命令 `gconftool-2'.
不然的話, 這個函數返回零 (zero).")

(scim-set-function-doc 
'scim-get-active-window-id
 "返回窗口係統中前台窗口的標識數字,
也就是輸入聚焦的窗口.")

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;; Define functions useful only for Traditional Chinese
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Settings

;; Functions

;;  (No such functions)

(provide 'scim-bridge-zh-tr)

;;;
;;; scim-bridge-zh-tr.el ends here
